@@ -25,9 +25,6 @@ df <- data.frame(species = c("e"), row.names = c("a"))
 range_emp <- SpatialPolygonsDataFrame(range, data = as.data.frame(df_miss))
 range <- SpatialPolygonsDataFrame(range, data = as.data.frame(df))
 
-wgs84 <- 
-  '+proj=cea +lon_0=0 +lat_ts=30 +x_0=0 +y_0=0 +datum=WGS84 +ellps=WGS84 +units=m +no_defs'
-
 # run tests
 ## cc_cap
 test_that("cc_cap works", {
@@ -54,20 +51,26 @@ test_that("cc_cen works", {
 ## cc_coun
 test_that("cc_coun works", {
 skip_on_cran()
+  library(rnaturalearthdata)
+  exmpl2 <-  data.frame(decimallatitude = c(51.5, -10), 
+                        decimallongitude = c(8, 40),
+                        countrycode = c("DEU", "DEU"))
+  
   cust_ref1 <- rnaturalearth::ne_countries(scale = "small")
-  names(cust_ref1)[names(cust_ref1) == "iso_a3"] <- "iso_a3_eh"
   cust_ref2 <- cust_ref1
-  proj4string(cust_ref2) <- ""
-  cust_ref3 <- spTransform(cust_ref1, 
-                           CRS(wgs84))
-  
-  
+  names(cust_ref2)[45] <- "iso_a3_eh"
+
   expect_is(cc_coun(exmpl, value = "flagged"), "logical")
   expect_is(cc_coun(exmpl, value = "clean"), "data.frame")
   
+  #customized references
+  expect_equal(nrow(cc_coun(x = exmpl2)), 1)
+  expect_error(cc_coun(x = exmpl2, ref = cust_ref1, ref_col = "test"))
+  expect_error(cc_coun(x = exmpl2, ref = cust_ref2))
+  expect_equal(nrow(cc_coun(x = exmpl2, ref = cust_ref2, ref_col = "iso_a3_eh")), 1)
+  
   
   expect_equal(sum(cc_coun(x = exmpl, value = "flagged", ref = cust_ref1)), 0)
-  expect_equal(sum(cc_coun(x = exmpl, value = "flagged", ref = cust_ref2)), 0)
   expect_equal(sum(cc_coun(x = exmpl, value = "flagged")), 0)
   
   expect_error(cc_coun(x = exmpl, lon = "longitude", value = "flagged"), 
@@ -115,10 +118,15 @@ skip_on_cran()
                            geod = FALSE, buffer = 0.01)), 251)
   
   expect_equal(sum(cc_inst(x = t.inst, 
-                           value = "flagged", verify = T)), 253)
+                           value = "flagged",
+                           verify = T)), 
+               253)
   expect_equal(sum(cc_inst(x = t.inst, 
-                           value = "flagged", verify = T, 
-                           geod = FALSE, buffer = 100)), 252)
+                           value = "flagged", 
+                           verify = T, 
+                           geod = FALSE, 
+                           buffer = 100)), 
+               252)
   
   expect_error(cc_inst(x = exmpl, lon = "longitude", value = "flagged"), 
                "undefined columns selected")
@@ -172,10 +180,7 @@ skip_on_cran()
                                                        category = "physical")
 
   proj4string(cust_ref2) <- ""
-  cust_ref3 <- spTransform(cust_ref1, 
-                           CRS(wgs84))
-  
-  
+
   expect_is(cc_sea(exmpl, value = "flagged", ref = cust_ref1), "logical")
   expect_is(cc_sea(exmpl, value = "clean", ref = cust_ref1), "data.frame")
   
